Пользователи имеют возможность входа в систему на базе **WEFRAM**, используя различные,
доступные и включенные в настройках проекта схемы авторизации, такие, как простой
логин-пароль или доменную авторизацию с использованием Active Directory.

Пользователи уникально идентифицируются своими логинами. Логин, кроме прочего,
может содержать так-же символ @, который используется для разделения, собственно,
имени пользователя и его принадлежности к определённому домену. В таком случае
логин пользователя указывается *до* символа @, а домен указывается *после*. Пример:

*username@domain.local*

В случае, если пользователь не доменный (не имеет символа @ в своём логине) - для
него в обязательном порядке требуется указание пароля. Локальный пользователь без
пароля не сможет войти в систему.


Временная блокировка
--------------------

В случае необходимости временной блокировки пользователя достаточно поставить
переключатель **Заблокировать** в активное положение. При этом пользователь не
будет удален из системы, все его данные, информация об активности и так далее
будут сохранены, но войти в систему он более не сможет.


Карточка пользователя
---------------------

Для существующих пользователей отображаются:

* *Время последнего входа* - дата и время когда пользователь в крайний раз входил в систему;
* *Дата создания* - по сути, это дата добавления пользователя в систему;

Поля карточки пользователя:
* *Имя пользователя* - уникальный логин пользователя, может содержать символ '@'. 
Имя пользователя должно быть уникально в пределах проекта. Причём пользователи с
одинаковым логином, но разными доменами не нарушают уникальность (это разные
пользователи,по факту);
* *Заблокирован* - если переключатель установлен, то пользователь будет заблокирован и
не сможет более войти в систему;
* *Фамилия*, *Имя*, *Отчество* - из всех перечисленных обязательно к заполнению только
поле *Имя*. Эти три поля формируют отображаемое имя пользователя в формате локали
текущего пользователя (в его языковом формате);
* *Пароль* и *Подтверждение* - служат для задания пароля; для смены пароля *существующего*
пользователя - введите его в эти поля и сохраните карточку; если для *существующего*
пользователя не вводить пароль, а оставить поля пустыми - пароль не будет изменён (будет
сохранён текущий пароль пользователя); для *нового* пользователя пустые поля обозначают
пустой пароль (допускается только для доменных пользователей);
* *Очистить пароль* - это кнопка справа от полеё ввода нового пароля, появляется (доступна)
только для доменных пользователей и позволяет удалить текущий пароль пользователя;
